@@ -22,6 +22,7 @@ from pptx.enum.chart import (
 )
 from pptx.enum.dml import MSO_FILL_TYPE, MSO_THEME_COLOR
 from pptx.parts.embeddedpackage import EmbeddedXlsxPart
+from pptx.text.text import Font
 from pptx.util import Inches
 
 from .helpers import count, test_pptx
@@ -179,6 +180,12 @@ def given_a_chart_of_type_chart_type(context, chart_type):
     context.chart = prs.slides[slide_idx].shapes[shape_idx].chart
 
 
+@given('a legend')
+def given_a_legend(context):
+    prs = Presentation(test_pptx('cht-legend-props'))
+    context.legend = prs.slides[0].shapes[0].chart.legend
+
+
 @given('a legend having horizontal offset of {value}')
 def given_a_legend_having_horizontal_offset_of_value(context, value):
     slide_idx = {
@@ -493,6 +500,12 @@ def then_I_can_access_the_chart_value_axis(context):
     assert isinstance(value_axis, ValueAxis)
 
 
+@then('legend.font is a Font object')
+def then_legend_font_is_a_Font_object(context):
+    legend = context.legend
+    assert isinstance(legend.font, Font)
+
+
 @then('legend.horz_offset is {value}')
 def then_legend_horz_offset_is_value(context, value):
     expected_value = float(value)
