@@ -62,6 +62,20 @@ def given_a_picture(context):
     context.shape = sld.shapes[1]
 
 
+@given('a rotated {shape_type}')
+def given_a_rotated_shape_type(context, shape_type):
+    shape_idx = {
+        'shape':         0,
+        'picture':       1,
+        'graphic frame': 2,
+        'group shape':   3,
+        'connector':     4,
+    }[shape_type]
+    prs = Presentation(test_pptx('shp-common-props'))
+    sld = prs.slides[1]
+    context.shape = sld.shapes[shape_idx]
+
+
 @given('a shape')
 def given_a_shape(context):
     prs = Presentation(test_pptx('shp-common-props'))
@@ -99,6 +113,12 @@ def given_an_autoshape(context):
     context.shape = shapes.add_shape(MSO_SHAPE.ROUNDED_RECTANGLE, x, y, cx, cy)
 
 
+@given('an autoshape having text')
+def given_an_autoshape_having_text(context):
+    prs = Presentation(test_pptx('shp-autoshape-props'))
+    context.shape = prs.slides[0].shapes[0]
+
+
 @given('I have a reference to a chevron shape')
 def given_ref_to_chevron_shape(context):
     context.prs = Presentation()
@@ -128,6 +148,21 @@ def when_I_add_an_auto_shape(context):
     sp.text = test_text
 
 
+@when("I assign a string to shape.text")
+def when_I_assign_a_string_to_shape_text(context):
+    context.shape.text = u'F\xf8o\nBar'
+
+
+@when("I assign '{value}' to shape.name")
+def when_I_assign_value_to_shape_name(context, value):
+    context.shape.name = value
+
+
+@when("I assign {value} to shape.rotation")
+def when_I_assign_value_to_shape_rotation(context, value):
+    context.shape.rotation = float(value)
+
+
 @when("I change the left and top of the {shape_type}")
 def when_I_change_the_position_of_the_shape(context, shape_type):
     left, top = {
@@ -197,7 +232,7 @@ def when_set_fore_color_to_RGB_value(context):
 def then_auto_shape_appears_in_slide(context):
     prs = Presentation(saved_pptx_path)
     sp = prs.slides[0].shapes[0]
-    sp_text = sp.textframe.paragraphs[0].runs[0].text
+    sp_text = sp.text_frame.paragraphs[0].runs[0].text
     assert sp.shape_type == MSO_SHAPE_TYPE.AUTO_SHAPE
     assert sp.auto_shape_type == MSO_SHAPE.ROUNDED_RECTANGLE
     assert sp_text == test_text
@@ -246,13 +281,13 @@ def then_I_can_access_the_slide_from_the_shape(context):
     assert context.shape.part is context.slide
 
 
-@then('I can determine the shape {has_textframe_status}')
-def then_the_shape_has_textframe_status(context, has_textframe_status):
-    has_textframe = {
+@then('I can determine the shape {has_text_frame_status}')
+def then_the_shape_has_text_frame_status(context, has_text_frame_status):
+    has_text_frame = {
         'has a text frame':  True,
         'has no text frame': False,
-    }[has_textframe_status]
-    assert context.shape.has_textframe is has_textframe
+    }[has_text_frame_status]
+    assert context.shape.has_text_frame is has_text_frame
 
 
 @then('I can get the id of the {shape_type}')
@@ -267,18 +302,30 @@ def then_I_can_get_the_id_of_the_shape(context, shape_type):
     assert context.shape.id == expected_id
 
 
-@then('I can get the name of the {shape_type}')
-def then_I_can_get_the_name_of_the_shape(context, shape_type):
-    expected_name = {
-        'shape':         'Rounded Rectangle 1',
-        'picture':       'Picture 2',
-        'graphic frame': 'Table 3',
-        'group shape':   'Group 8',
-        'connector':     'Elbow Connector 10',
-    }[shape_type]
+@then("shape.name is '{expected_value}'")
+def then_shape_name_is_value(context, expected_value):
     shape = context.shape
-    msg = "expected shape name '%s', got '%s'" % (shape.name, expected_name)
-    assert shape.name == expected_name, msg
+    msg = "expected shape name '%s', got '%s'" % (shape.name, expected_value)
+    assert shape.name == expected_value, msg
+
+
+@then("shape.rotation is {value}")
+def then_shape_rotation_is_value(context, value):
+    shape = context.shape
+    expected_value = float(value)
+    assert shape.rotation == expected_value, 'got %s' % expected_value
+
+
+@then('shape.text is the string I assigned')
+def then_shape_text_is_the_string_I_assigned(context):
+    shape = context.shape
+    assert shape.text == u'F\xf8o\nBar'
+
+
+@then('shape.text is the text in the shape')
+def then_shape_text_is_the_text_in_the_shape(context):
+    shape = context.shape
+    assert shape.text == u'Fee Fi\nF\xf8\xf8 Fum\nI am a shape\nwith textium'
 
 
 @then('the chart is a Chart object')
@@ -353,5 +400,5 @@ def then_width_and_height_of_shape_match_new_values(context, shape_type):
 def then_text_box_appears_in_slide(context):
     prs = Presentation(saved_pptx_path)
     textbox = prs.slides[0].shapes[0]
-    textbox_text = textbox.textframe.paragraphs[0].runs[0].text
+    textbox_text = textbox.text_frame.paragraphs[0].runs[0].text
     assert textbox_text == test_text
