@@ -79,6 +79,7 @@ class CT_Shape(BaseShapeElement):
     """
     nvSpPr = OneAndOnlyOne('p:nvSpPr')
     spPr = OneAndOnlyOne('p:spPr')
+    txBody = ZeroOrOne('p:txBody', successors=('p:extLst',))
 
     def get_or_add_ln(self):
         """
@@ -228,6 +229,9 @@ class CT_Shape(BaseShapeElement):
             (nsdecls('a', 'p'), '%d', '%s', '%d', '%d', '%d', '%d', '%s')
         )
 
+    def _new_txBody(self):
+        return CT_TextBody.new_p_txBody()
+
     @staticmethod
     def _ph_sp_tmpl():
         return (
