@@ -13,8 +13,9 @@ from ..enum.text import (
 )
 from .ns import nsdecls
 from .simpletypes import (
-    ST_Coordinate32, ST_TextFontSize, ST_TextIndentLevelType,
-    ST_TextTypeface, ST_TextWrappingType, XsdBoolean, XsdString
+    ST_Coordinate32, ST_TextFontScalePercentOrPercentString, ST_TextFontSize,
+    ST_TextIndentLevelType, ST_TextTypeface, ST_TextWrappingType, XsdBoolean,
+    XsdString
 )
 from ..util import Emu, to_unicode
 from .xmlchemy import (
@@ -233,6 +234,7 @@ class CT_TextField(BaseOxmlElement):
     """
     <a:fld> field element, for either a slide number or date field
     """
+    rPr = ZeroOrOne('a:rPr', successors=('a:pPr', 'a:t'))
     t = ZeroOrOne('a:t', successors=())
 
     @property
@@ -259,6 +261,8 @@ class CT_TextLineBreak(BaseOxmlElement):
     """
     <a:br> line break element
     """
+    rPr = ZeroOrOne('a:rPr', successors=())
+
     @property
     def text(self):
         """
@@ -268,6 +272,15 @@ class CT_TextLineBreak(BaseOxmlElement):
         return u'\n'
 
 
+class CT_TextNormalAutofit(BaseOxmlElement):
+    """
+    <a:normAutofit> element specifying fit text to shape font reduction, etc.
+    """
+    fontScale = OptionalAttribute(
+        'fontScale', ST_TextFontScalePercentOrPercentString, default=100.0
+    )
+
+
 class CT_TextParagraph(BaseOxmlElement):
     """
     <a:p> custom element class
